@@ -45,6 +45,7 @@ def sql_string_from_query_set(qs, *args):
     return sql
 
 def import_from_string(path):
-    class_name = path.split('.')[-1]
-    package_package = '.'.join(path.split('.')[:-1])
-    return getattr(__import__(package_package, fromlist=[class_name]), class_name)
\ No newline at end of file
+    path_components = path.split('.')
+    class_name = path_components[-1]
+    package = '.'.join(path_components[:-1])
+    return getattr(__import__(package, fromlist=[class_name]), class_name)
\ No newline at end of file
